pub fn find(scheme: &str) -> Option<&'static dyn TransportKind>Expand description
Find the registered kind that owns scheme, if any.
pub fn find(scheme: &str) -> Option<&'static dyn TransportKind>Find the registered kind that owns scheme, if any.